#!/usr/bin/python3
#  coding:  utf-8
#
#   folderContHddVals.py
#
#       folderContやHDDの容量を取得する
#
#   21/05/09    新規作成
#

import os
import shutil
import glob
import abaqus2fistr

#
#  getFolderCont
#----------------
def getFolderCont(folderDir):
    """ folderの内容を取得する"""

    #
    #  isCaseDir
    def isCaseDir(folderDir):
        """ caseDirかどうかチェックする"""
        if os.path.exists(folderDir + os.sep + "FistrModel.cnt") == True:
            return True
        return False

    #
    #  getFolType
    def getFolType(folderDir):
        """ folderTypeを取得する。case, caseLink, folder, foldeLink"""
        if os.path.exists(folderDir + os.sep + "FistrModel.cnt") == True:
            folType = "case"
        else:
            folType = "folder"
        #linkのcheck
        #  windowsのshortCutは、認識しない。
        if os.path.islink(folderDir) == True:
            folType += "Link"
        return folType

    #
    #  getModelName
    def getModelName(folderDir):
        """ mesh変換時のinp or unv ファイル名を取得"""
        model = ""
        fileName = folderDir + os.sep + "easyIstrSub_data"
        if os.path.exists(fileName) == False:
            return model
        f = open(fileName, encoding="utf-8"); lines = f.readlines(); f.close()
        for line in lines:
            if line[:len("sourceMesh")] == "sourceMesh":
                words = line.split()
                if len(words) > 1:
                    model = words[1]
                break
        return model

    #
    #  getCaseCont
    def getCaseCont(folderDir):
        """ caseの内容（solType, solver, meshSize, nRes）を取得"""
        solType = ""
        solver = ""
        nRes = ""
        meshSize = ""
        fileName = folderDir + os.sep + "FistrModel.cnt"
        f = open(fileName, encoding="utf-8"); lines = f.readlines(); f.close()
        #solutionをチェック
        ist = 0
        for i in range(len(lines)):
            line = lines[i]
            if line[:len("!SOLUTION")].upper() == "!SOLUTION":
                solType = abaqus2fistr.getValName(line, "TYPE").upper()
                ist = i
                break
        if solType == "HEAT":
            #HEATの場合は、定常・非定常を確認
            for i in range(ist, len(lines)):
                line = lines[i]
                if line[:len("!HEAT")].upper() == "!HEAT":
                    words = lines[i+1].replace(" ", "").split(",")
                    try:
                        a = float(words[0])
                        if a != 0.0:
                            #非定常
                            solType = "HEAT_dy"
                    except:
                        pass
        #solverを取得
        for line in lines:
            if line[:len("!SOLVER")].upper() == "!SOLVER":
                solver = abaqus2fistr.getValName(line, "METHOD")
                break
        #meshSizeを取得
        meshFile = folderDir + os.sep + "FistrModel.msh"
        if os.path.exists(meshFile):
            meshSize = "%10.3f" % (os.path.getsize(meshFile)/1000000)
        #結果数nResを取得
        nRes = getNumberOfResults(folderDir)
        #nRes = ("%4d" % n) + " "
        return (solType, solver, meshSize, nRes)

    folType, model, solType, solver, meshSize, nRes = "folder", "", "", "", "", ""
    folType = getFolType(folderDir)
    if folType == "case" or folType == "caseLink":
        model = getModelName(folderDir)
        (solType, solver, meshSize, nRes) = getCaseCont(folderDir)
    return [folType, solType, solver, model, meshSize, nRes]

#
#  getNumResults
#---------------------
def getNumResults(folderDir):
    """ 結果のflder数を取得"""
    
    def getNumPatterns(folderDir, patterns):
        n = 0
        for pattern in patterns:
            patt = folderDir + os.sep + pattern
            n += len(glob.glob(patt))
        return n
    
    vtuPatterns = ["FistrModel.vis_psf.*.pvtu"]
    resPatterns = ["FistrModel.res.0.*",
                    "FistrModel_eigen.res.0.*",
                    "FistrModel_temp.res.0.*",
                    "FistrModel_dyna.res.0.*"]
    nVtu = getNumPatterns(folderDir, vtuPatterns)
    nRes = getNumPatterns(folderDir, resPatterns)
    n = max([nVtu, nRes])
    return n

#
#  getNumberOfResults
def getNumberOfResults(folderDir):
    n = getNumResults(folderDir)
    nRes = ("%4d" % n) + " "
    return nRes

#
#  getDiskSpase
#---------------
def getDiskSpace(folderDir):
    """ HDDの使用状況を取得して返す。
    vals(total, usage, free)
    total: disk.total
    usage: disk.usage
    free :disk.free
    """
    disk = shutil.disk_usage(folderDir)
    return disk
