#!/usr/bin/python3
#  coding: utf-8
#
#       inputMaterialContDDialog.py
#
#           非線形材料データの入力dialog
#
#   22/04/13    新規作成
#

import gi
gi.require_version("Gtk", "3.0")
from gi.repository import Gtk
import os, sys

ls = "\n"

#--------------------
#  dialogApp class
#--------------------
class dialogApp:
    """ 非線形材料データの入力dialog"""

    def __init__(self, matModelTypeHard, labelNames, mat3Vals, labelConts):
        self.builder = Gtk.Builder()
        path = os.getenv("easyIstrPath") + os.sep + "python" + os.sep
        self.builder.add_from_file(path + "inputMaterialContDDialog.glade")
        self.dialog = self.builder.get_object("dialog1")
        self.dialog.connect("delete-event", self.close)
        self.builder.connect_signals(self)
        self.setGtkObject()
        #変数の設定
        self.matModel = matModelTypeHard[0]
        self.matType = matModelTypeHard[1]
        self.matHard = matModelTypeHard[2]
        self.labelNames = labelNames
        self.mat3Vals = mat3Vals
        self.labelConts = labelConts
        self.stat = "CANCEL"
        #初期化
        self.initilize()

    #
    #  show
    #--------
    def show(self):
        self.dialog.run()
        if self.stat != "OK":
            return []
        else:
            return self.mat3Vals

    #
    #  close
    #-----------
    def close(self, *args):
        self.dialog.destroy()

    # ----------- event handler -------------------
    def onOk(self, event):
        self.stat = "OK"
        self.mat3Vals = self.getVals()
        self.close()

    def onCancel(self, event):
        self.stat = "CANCEL"
        self.mat3Vals = []
        self.close()

    #
    #  setGtkObject
    #----------------
    def setGtkObject(self):
        self.label_subTitle = self.builder.get_object("label_subTitle")
        self.label_name0 = self.builder.get_object("label_name0")
        self.label_name1 = self.builder.get_object("label_name1")
        self.label_name2 = self.builder.get_object("label_name2")
        self.entry_val0 = self.builder.get_object("entry_val0") 
        self.entry_val1 = self.builder.get_object("entry_val1") 
        self.entry_val2 = self.builder.get_object("entry_val2")
        self.label_cont0 = self.builder.get_object("label_cont0")
        self.label_cont1 = self.builder.get_object("label_cont1")
        self.label_cont2 = self.builder.get_object("label_cont2")
        #文字をセット
        self.builder.get_object("button_ok").get_child().set_text("OK")
        self.builder.get_object("button_cancel").get_child().set_text(_("キャンセル"))

    #
    #  initilize
    #------------
    def initilize(self):
        """ 初期化"""
        #title設定
        self.dialog.set_title(_("材料定数の設定"))
        mess = self.matModel + ls + self.matType + ls + self.matHard
        self.label_subTitle.set_text(mess)
        if self.labelNames[0] != "":
            self.label_name0.set_sensitive(True)
            self.entry_val0.set_sensitive(True)
            self.label_cont0.set_sensitive(True)
            self.label_name0.set_text(self.labelNames[0])
            self.entry_val0.set_text(self.mat3Vals[0])
            self.label_cont0.set_text(self.labelConts[0])
        else:
            self.label_name0.set_text("")
            self.entry_val0.set_text("")
            self.label_cont0.set_text("")
            self.label_name0.set_sensitive(False)
            self.entry_val0.set_sensitive(False)
            self.label_cont0.set_sensitive(False)
        
        if self.labelNames[1] != "":
            self.label_name1.set_sensitive(True)
            self.entry_val1.set_sensitive(True)
            self.label_cont1.set_sensitive(True)
            self.label_name1.set_text(self.labelNames[1])
            self.entry_val1.set_text(self.mat3Vals[1])
            self.label_cont1.set_text(self.labelConts[1])
        else:
            self.label_name1.set_text("")
            self.entry_val1.set_text("")
            self.label_cont1.set_text("")
            self.label_name1.set_sensitive(False)
            self.entry_val1.set_sensitive(False)
            self.label_cont1.set_sensitive(False)
            
        if self.labelNames[2] != "":
            self.label_name2.set_sensitive(True)
            self.entry_val2.set_sensitive(True)
            self.label_cont2.set_sensitive(True)
            self.label_name2.set_text(self.labelNames[2])
            self.entry_val2.set_text(self.mat3Vals[2])
            self.label_cont2.set_text(self.labelConts[2])
        else:
            self.label_name2.set_text("")
            self.entry_val2.set_text("")
            self.label_cont2.set_text("")
            self.label_name2.set_sensitive(False)
            self.entry_val2.set_sensitive(False)
            self.label_cont2.set_sensitive(False)

    #
    #  getVals
    #----------
    def getVals(self):
        """ entry内のtextを取得"""
        val0 = self.entry_val0.get_text()
        val1 = self.entry_val1.get_text()
        val2 = self.entry_val2.get_text()
        return [val0, val1, val2]

if __name__ == "__main__":
    import gettext
    gettext.install("easyistr", os.getenv("LOCALE_DIR"))

    mats = ["PLASTIC", "MISES", "BILINEAR"]
    names = ["YIELD0", "H", ""]
    conts = ["初期降伏応力", "硬化係数", ""]
    vals = ["0", "0", ""]
    dialog = dialogApp(mats, names, vals, conts)
    dialog.show()
